All Classes and Interfaces

Class
Description
Additional global ignore settings that are used to reduce number of classes we try to apply expensive matchers to.
 
 
An AgentExtension provides a way to modify/enrich the OpenTelemetry Javaagent behavior.
 
Main entry point into code that is running inside agent class loader, used reflectively from io.opentelemetry.javaagent.bootstrap.AgentInitializer.
 
 
 
Internal listener SPI that runs before the instrumentation is installed.
This interface exposes a way to define which packages/classes are present in the bootstrap class loader.
 
This SPI can be used to define which packages/classes belong to the bootstrap class loader: all packages configured here will always be loaded by the bootstrap class loader, even if class loader that initiated loading of the class does not normally delegate to bootstrap class loader.
 
 
 
Some useful constants.
 
Agent config class that is only supposed to be used before the SDK (and ConfigProperties) is initialized.
 
 
This class creates a class loader which encapsulates arbitrary extensions for Otel Java instrumentation agent.
 
 
 
 
 
A matcher wrapper that skips matching and returns false when it is known that loading the matched type will fail.
 
 
 
 
A fail-safe matcher catches exceptions that are thrown by a delegate matcher and returns false.
 
 
A matcher wrapper that adds specified name to the output of toString to allow easy identification of where the given matcher originates from.
 
 
 
Wrapper for AgentBuilder.TypeStrategy that excludes methods with missing return or parameter types.
 
 
A prefix tree that maps from the longest matching prefix to a value V.