Class AgentTooling
- java.lang.Object
-
- io.opentelemetry.javaagent.tooling.AgentTooling
-
public final class AgentTooling extends Object
This class contains class references for objects shared by the agent installer as well as muzzle (both compile and runtime). Extracted out from AgentInstaller to begin separating some of the logic out.
-
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static AgentLocationStrategylocationStrategy()static AgentCachingPoolStrategypoolStrategy()
-
-
-
Method Detail
-
locationStrategy
public static AgentLocationStrategy locationStrategy()
-
poolStrategy
public static AgentCachingPoolStrategy poolStrategy()
-
-