Class Constants
- java.lang.Object
-
- io.opentelemetry.javaagent.tooling.Constants
-
public final class Constants extends Object
Some useful constants.Idea here is to keep this class safe to inject into client's class loader.
-
-
Field Detail
-
BOOTSTRAP_PACKAGE_PREFIXES
public static final String[] BOOTSTRAP_PACKAGE_PREFIXES
packages which will be loaded on the bootstrap classloader.
-
-