Class GuavaWeakCache<K,V>
- java.lang.Object
-
- io.opentelemetry.javaagent.tooling.GuavaWeakCache<K,V>
-
- All Implemented Interfaces:
io.opentelemetry.javaagent.bootstrap.WeakCache<K,V>
public final class GuavaWeakCache<K,V> extends Object implements io.opentelemetry.javaagent.bootstrap.WeakCache<K,V>
No null keys nor null values are permitted.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classGuavaWeakCache.Provider<K,V>
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description Vget(K key, Callable<? extends V> loader)VgetIfPresent(K key)Returns null if key is not present.VgetIfPresentOrCompute(K key, Callable<? extends V> loader)voidput(K key, V value)
-