Interface LoggingCustomizer

All Known Implementing Classes:
NoopLoggingCustomizer

public interface LoggingCustomizer
  • Method Summary

    Modifier and Type
    Method
    Description
    void
     
    Returns name of the logger implementation.
    void
    Register a callback which will be called on synchronous startup failure (including if init() fails).
    void
    Register a callback which will be called on synchronous startup success.
  • Method Details

    • name

      String name()
      Returns name of the logger implementation. Will be matched against the value of the otel.javavagent.logger system property - in case it is the same, this LoggingCustomizer will be used to initialize the javaagent logging subsystem.
    • init

      void init()
    • onStartupSuccess

      void onStartupSuccess()
      Register a callback which will be called on synchronous startup success.

      Synchronous startup may or may not include running AgentListener.afterAgent(AutoConfiguredOpenTelemetrySdk)" listeners.

    • onStartupFailure

      void onStartupFailure(Throwable throwable)
      Register a callback which will be called on synchronous startup failure (including if init() fails).

      Synchronous startup may or may not include running AgentListener.afterAgent(AutoConfiguredOpenTelemetrySdk)" listeners.