Interface BootstrapPackagesBuilder

All Known Implementing Classes:
BootstrapPackagesBuilderImpl

public interface BootstrapPackagesBuilder
This interface exposes a way to define which packages/classes are present in the bootstrap classloader.

This interface should not be implemented by the javaagent extension developer - the javaagent will provide the implementation.

  • Method Details