Class AgentLocationStrategy

  • All Implemented Interfaces:
    net.bytebuddy.agent.builder.AgentBuilder.LocationStrategy

    public class AgentLocationStrategy
    extends java.lang.Object
    implements net.bytebuddy.agent.builder.AgentBuilder.LocationStrategy
    Locate resources with the loading classloader. Because of a quirk with the way classes appended to the bootstrap classpath work, we first check our bootstrap proxy. If the loading classloader cannot find the desired resource, check up the classloader hierarchy until a resource is found.
    • Nested Class Summary

      • Nested classes/interfaces inherited from interface net.bytebuddy.agent.builder.AgentBuilder.LocationStrategy

        net.bytebuddy.agent.builder.AgentBuilder.LocationStrategy.Compound, net.bytebuddy.agent.builder.AgentBuilder.LocationStrategy.ForClassLoader, net.bytebuddy.agent.builder.AgentBuilder.LocationStrategy.NoOp, net.bytebuddy.agent.builder.AgentBuilder.LocationStrategy.Simple
    • Method Summary

      All Methods Instance Methods Concrete Methods 
      Modifier and Type Method Description
      net.bytebuddy.dynamic.ClassFileLocator classFileLocator​(java.lang.ClassLoader classLoader)  
      net.bytebuddy.dynamic.ClassFileLocator classFileLocator​(java.lang.ClassLoader classLoader, net.bytebuddy.utility.JavaModule javaModule)  
      • Methods inherited from class java.lang.Object

        equals, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

      • AgentLocationStrategy

        public AgentLocationStrategy()
    • Method Detail

      • classFileLocator

        public net.bytebuddy.dynamic.ClassFileLocator classFileLocator​(java.lang.ClassLoader classLoader)
      • classFileLocator

        public net.bytebuddy.dynamic.ClassFileLocator classFileLocator​(java.lang.ClassLoader classLoader,
                                                                       net.bytebuddy.utility.JavaModule javaModule)
        Specified by:
        classFileLocator in interface net.bytebuddy.agent.builder.AgentBuilder.LocationStrategy