Class LoggingFailSafeMatcher<T>
- java.lang.Object
-
- net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<T>
-
- io.opentelemetry.javaagent.tooling.bytebuddy.LoggingFailSafeMatcher<T>
-
- Type Parameters:
T- The type of the matched entity.
- All Implemented Interfaces:
net.bytebuddy.matcher.ElementMatcher<T>,net.bytebuddy.matcher.ElementMatcher.Junction<T>
public class LoggingFailSafeMatcher<T> extends net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<T>A fail-safe matcher catches exceptions that are thrown by a delegate matcher and returnsfalse.Logs exception if it was thrown.
- See Also:
FailSafeMatcher
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface net.bytebuddy.matcher.ElementMatcher
net.bytebuddy.matcher.ElementMatcher.Junction<S extends Object>
-
Nested classes/interfaces inherited from interface net.bytebuddy.matcher.ElementMatcher.Junction
net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<V extends Object>, net.bytebuddy.matcher.ElementMatcher.Junction.Conjunction<W extends Object>, net.bytebuddy.matcher.ElementMatcher.Junction.Disjunction<W extends Object>
-
-
Constructor Summary
Constructors Constructor Description LoggingFailSafeMatcher(net.bytebuddy.matcher.ElementMatcher<? super T> matcher, String description)Creates a new fail-safe element matcher.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)inthashCode()booleanmatches(T target)StringtoString()
-
-
-
Constructor Detail
-
LoggingFailSafeMatcher
public LoggingFailSafeMatcher(net.bytebuddy.matcher.ElementMatcher<? super T> matcher, String description)
Creates a new fail-safe element matcher.- Parameters:
matcher- The delegate matcher that might throw an exception.description- Descriptive string to log along with exception.
-
-