Package io.opentelemetry.javaagent.tooling.bytebuddy
-
Class Summary Class Description ExceptionHandlers LoggingFailSafeMatcher<T> A fail-safe matcher catches exceptions that are thrown by a delegate matcher and returnsfalse.
| Class | Description |
|---|---|
| ExceptionHandlers | |
| LoggingFailSafeMatcher<T> |
A fail-safe matcher catches exceptions that are thrown by a delegate matcher and returns
false. |