Package io.opentelemetry.javaagent.tooling.config
package io.opentelemetry.javaagent.tooling.config
-
ClassesClassDescriptionAgent config class that is only supposed to be used before the SDK (and
ConfigProperties) is initialized.Allows access to the Javaagent distribution node, which cannot be accessed using theConfigProviderAPI.