Class NoopContextProvider
- java.lang.Object
-
- io.opentelemetry.javaagent.tooling.context.NoopContextProvider
-
- All Implemented Interfaces:
InstrumentationContextProvider
public class NoopContextProvider extends Object implements InstrumentationContextProvider
-
-
Field Summary
Fields Modifier and Type Field Description static NoopContextProviderINSTANCE
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description net.bytebuddy.agent.builder.AgentBuilder.Identified.ExtendableadditionalInstrumentation(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)Hook to define additional instrumentation.net.bytebuddy.agent.builder.AgentBuilder.Identified.ExtendableinstrumentationTransformer(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)Hook to provide an agent builder after advice is applied to target class.
-
-
-
Field Detail
-
INSTANCE
public static final NoopContextProvider INSTANCE
-
-
Method Detail
-
instrumentationTransformer
public net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable instrumentationTransformer(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)
Description copied from interface:InstrumentationContextProviderHook to provide an agent builder after advice is applied to target class. Used to implement context-store lookup.- Specified by:
instrumentationTransformerin interfaceInstrumentationContextProvider
-
additionalInstrumentation
public net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable additionalInstrumentation(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)
Description copied from interface:InstrumentationContextProviderHook to define additional instrumentation. Run at instrumentation advice is hooked up.- Specified by:
additionalInstrumentationin interfaceInstrumentationContextProvider
-
-