Interface VirtualFieldImplementationInstaller


  • public interface VirtualFieldImplementationInstaller
    • Method Summary

      All Methods Instance Methods Abstract Methods 
      Modifier and Type Method Description
      net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable injectFields​(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)
      Injects actual fields in classes referenced by VirtualField usages.
      net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable rewriteVirtualFieldsCalls​(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)
      Rewrites VirtualField.find(Class, Class) so that they return the real implementation, generated by this class.
    • Method Detail

      • rewriteVirtualFieldsCalls

        net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable rewriteVirtualFieldsCalls​(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)
        Rewrites VirtualField.find(Class, Class) so that they return the real implementation, generated by this class. Injects helper classes required to make this the actual VirtualField implementations work.
      • injectFields

        net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable injectFields​(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)
        Injects actual fields in classes referenced by VirtualField usages.