Class InstrumentationLoader

    • Constructor Detail

      • InstrumentationLoader

        public InstrumentationLoader()
    • Method Detail

      • extend

        public net.bytebuddy.agent.builder.AgentBuilder extend​(net.bytebuddy.agent.builder.AgentBuilder agentBuilder)
        Description copied from interface: AgentExtension
        Extend the passed agentBuilder with custom logic (e.g. instrumentation).
        Specified by:
        extend in interface AgentExtension
        Returns:
        The customized agent. Note that this method MUST return a non-null AgentBuilder instance that contains all customizations defined in this extension.
      • extensionName

        public String extensionName()
        Description copied from interface: AgentExtension
        Returns the name of the extension. It does not have to be unique, but it should be human-readable: javaagent uses the extension name in its logs.
        Specified by:
        extensionName in interface AgentExtension