Class GlobalIgnoresMatcher<T extends net.bytebuddy.description.type.TypeDescription>

  • All Implemented Interfaces:
    net.bytebuddy.matcher.ElementMatcher<T>, net.bytebuddy.matcher.ElementMatcher.Junction<T>

    public class GlobalIgnoresMatcher<T extends net.bytebuddy.description.type.TypeDescription>
    extends net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<T>
    Global ignores matcher used by the agent.

    This matcher services two main purposes:

    • Ignore classes that are unsafe or pointless to transform. 'System' level classes like jvm classes or groovy classes, other tracers, debuggers, etc.