Package io.opentelemetry.javaagent.tooling.matcher
-
Class Summary Class Description AdditionalLibraryIgnoresMatcher Additional global matchers that are used to reduce number of classes we try to apply expensive matchers to.GlobalClassloaderIgnoresMatcher GlobalIgnoresMatcher Global ignores matcher used by the agent.