Class Reference


  • public final class Reference
    extends Object
    This class represents a reference to a Java class used in an instrumentation advice code. LinkedHashSet is used for all sets to guarantee a deterministic order of iteration, so that bytecode generated based on them would also be deterministic.
    • Method Detail

      • getClassName

        public String getClassName()
      • getSuperName

        public @Nullable String getSuperName()
      • getInterfaces

        public Set<String> getInterfaces()
      • merge

        public Reference merge​(Reference anotherReference)
        Create a new reference which combines this reference with another reference of the same type.
        Parameters:
        anotherReference - A reference to the same class
        Returns:
        a new Reference which merges the two references