Interface Reference.Flag
-
- All Known Implementing Classes:
Reference.Flag.ManifestationFlag,Reference.Flag.MinimumVisibilityFlag,Reference.Flag.OwnershipFlag,Reference.Flag.VisibilityFlag
- Enclosing class:
- Reference
public static interface Reference.FlagExpected flag (or lack of flag) on a class, method or field reference.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static classReference.Flag.ManifestationFlagThe constants of this enum describe whether a method or class is abstract, final or non-final.static classReference.Flag.MinimumVisibilityFlagThe constants of this enum represent the minimum visibility flag required by a type access, method call or field access.static classReference.Flag.OwnershipFlagThe constants of this enum describe whether a method/field is static or not.static classReference.Flag.VisibilityFlagThe constants of this enum represent the exact visibility of a referenced class, method or field.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description booleanmatches(int asmFlags)Predicate method that determines whether this flag is present in the passed bitmask.Stringname()Same asEnum.name().
-
-
-
Method Detail
-
matches
boolean matches(int asmFlags)
Predicate method that determines whether this flag is present in the passed bitmask.- See Also:
Opcodes
-
name
String name()
Same asEnum.name().
-
-