Enum Reference.Flag.MinimumVisibilityFlag
- java.lang.Object
-
- java.lang.Enum<Reference.Flag.MinimumVisibilityFlag>
-
- io.opentelemetry.javaagent.tooling.muzzle.Reference.Flag.MinimumVisibilityFlag
-
- All Implemented Interfaces:
Reference.Flag,Serializable,Comparable<Reference.Flag.MinimumVisibilityFlag>
- Enclosing interface:
- Reference.Flag
public static enum Reference.Flag.MinimumVisibilityFlag extends Enum<Reference.Flag.MinimumVisibilityFlag> implements Reference.Flag
The constants of this enum represent the minimum visibility flag required by a type access, method call or field access.- See Also:
Visibility
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface io.opentelemetry.javaagent.tooling.muzzle.Reference.Flag
Reference.Flag.ManifestationFlag, Reference.Flag.MinimumVisibilityFlag, Reference.Flag.OwnershipFlag, Reference.Flag.VisibilityFlag
-
-
Enum Constant Summary
Enum Constants Enum Constant Description PACKAGE_OR_HIGHERPRIVATE_OR_HIGHERPROTECTED_OR_HIGHERPUBLIC
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static Reference.Flag.MinimumVisibilityFlagvalueOf(String name)Returns the enum constant of this type with the specified name.static Reference.Flag.MinimumVisibilityFlag[]values()Returns an array containing the constants of this enum type, in the order they are declared.-
Methods inherited from class java.lang.Enum
compareTo, equals, getDeclaringClass, hashCode, name, ordinal, toString, valueOf
-
Methods inherited from interface io.opentelemetry.javaagent.tooling.muzzle.Reference.Flag
matches, name
-
-
-
-
Enum Constant Detail
-
PUBLIC
public static final Reference.Flag.MinimumVisibilityFlag PUBLIC
-
PROTECTED_OR_HIGHER
public static final Reference.Flag.MinimumVisibilityFlag PROTECTED_OR_HIGHER
-
PACKAGE_OR_HIGHER
public static final Reference.Flag.MinimumVisibilityFlag PACKAGE_OR_HIGHER
-
PRIVATE_OR_HIGHER
public static final Reference.Flag.MinimumVisibilityFlag PRIVATE_OR_HIGHER
-
-
Method Detail
-
values
public static Reference.Flag.MinimumVisibilityFlag[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (Reference.Flag.MinimumVisibilityFlag c : Reference.Flag.MinimumVisibilityFlag.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static Reference.Flag.MinimumVisibilityFlag valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
-