Enum Reference.Flag.VisibilityFlag
- java.lang.Object
-
- java.lang.Enum<Reference.Flag.VisibilityFlag>
-
- io.opentelemetry.javaagent.tooling.muzzle.Reference.Flag.VisibilityFlag
-
- All Implemented Interfaces:
Reference.Flag,Serializable,Comparable<Reference.Flag.VisibilityFlag>
- Enclosing interface:
- Reference.Flag
public static enum Reference.Flag.VisibilityFlag extends Enum<Reference.Flag.VisibilityFlag> implements Reference.Flag
The constants of this enum represent the exact visibility of a referenced class, method or field.- See Also:
Visibility
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface io.opentelemetry.javaagent.tooling.muzzle.Reference.Flag
Reference.Flag.ManifestationFlag, Reference.Flag.MinimumVisibilityFlag, Reference.Flag.OwnershipFlag, Reference.Flag.VisibilityFlag
-
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static Reference.Flag.VisibilityFlagvalueOf(String name)Returns the enum constant of this type with the specified name.static Reference.Flag.VisibilityFlag[]values()Returns an array containing the constants of this enum type, in the order they are declared.-
Methods inherited from class java.lang.Enum
compareTo, equals, getDeclaringClass, hashCode, name, ordinal, toString, valueOf
-
Methods inherited from interface io.opentelemetry.javaagent.tooling.muzzle.Reference.Flag
matches, name
-
-
-
-
Enum Constant Detail
-
PUBLIC
public static final Reference.Flag.VisibilityFlag PUBLIC
-
PROTECTED
public static final Reference.Flag.VisibilityFlag PROTECTED
-
PACKAGE
public static final Reference.Flag.VisibilityFlag PACKAGE
-
PRIVATE
public static final Reference.Flag.VisibilityFlag PRIVATE
-
-
Method Detail
-
values
public static Reference.Flag.VisibilityFlag[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (Reference.Flag.VisibilityFlag c : Reference.Flag.VisibilityFlag.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static Reference.Flag.VisibilityFlag valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
-