Class MuzzleCodeGenerationPlugin
- java.lang.Object
-
- io.opentelemetry.javaagent.tooling.muzzle.collector.MuzzleCodeGenerationPlugin
-
- All Implemented Interfaces:
java.io.Closeable,java.lang.AutoCloseable,net.bytebuddy.build.Plugin,net.bytebuddy.matcher.ElementMatcher<net.bytebuddy.description.type.TypeDescription>
public class MuzzleCodeGenerationPlugin extends java.lang.Object implements net.bytebuddy.build.PluginThis class is a ByteBuddy build plugin that is responsible for generating actual implementation of theInstrumentationModule.getMuzzleReferenceMatcher()method.This class is used in the gradle build scripts, referenced by each instrumentation module.
-
-
Constructor Summary
Constructors Constructor Description MuzzleCodeGenerationPlugin()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description net.bytebuddy.dynamic.DynamicType.Builder<?>apply(net.bytebuddy.dynamic.DynamicType.Builder<?> builder, net.bytebuddy.description.type.TypeDescription typeDescription, net.bytebuddy.dynamic.ClassFileLocator classFileLocator)voidclose()booleanmatches(net.bytebuddy.description.type.TypeDescription target)
-
-
-
Method Detail
-
matches
public boolean matches(net.bytebuddy.description.type.TypeDescription target)
- Specified by:
matchesin interfacenet.bytebuddy.matcher.ElementMatcher<net.bytebuddy.description.type.TypeDescription>
-
apply
public net.bytebuddy.dynamic.DynamicType.Builder<?> apply(net.bytebuddy.dynamic.DynamicType.Builder<?> builder, net.bytebuddy.description.type.TypeDescription typeDescription, net.bytebuddy.dynamic.ClassFileLocator classFileLocator)- Specified by:
applyin interfacenet.bytebuddy.build.Plugin
-
close
public void close()
- Specified by:
closein interfacejava.lang.AutoCloseable- Specified by:
closein interfacejava.io.Closeable
-
-