Package io.opentelemetry.javaagent.tooling.muzzle.collector
-
Class Summary Class Description MuzzleCodeGenerationPlugin This class is a ByteBuddy build plugin that is responsible for generating actual implementation of someInstrumentationModulemethods.ReferenceCollector LinkedHashMapis used for reference map to guarantee a deterministic order of iteration, so that bytecode generated based on it would also be deterministic. -
Exception Summary Exception Description MuzzleCompilationException