Interface HelperReferenceWrapper


  • public interface HelperReferenceWrapper
    This class provides a common interface for Reference and TypeDescription.
    • Method Detail

      • isAbstract

        boolean isAbstract()
      • hasSuperTypes

        boolean hasSuperTypes()
        Returns true if the wrapped type extends any class other than Object or implements any interface.
      • getSuperTypes

        Stream<HelperReferenceWrapper> getSuperTypes()
        Returns an iterable containing the wrapped type's super class (if exists) and implemented interfaces.