Package io.opentelemetry.javaagent.tooling.muzzle.matcher
-
Class Summary Class Description Mismatch A mismatch between aClassRefand a runtime class.Mismatch.MissingClass Mismatch.MissingField Mismatch.MissingFlag Mismatch.MissingMethod Mismatch.ReferenceCheckError Fallback mismatch in case an unexpected exception occurs during reference checking.MuzzleGradlePluginUtil Entry point for the muzzle gradle plugin.ReferenceMatcher Matches a set of references against a classloader.