Package io.opentelemetry.javaagent.tooling.muzzle
-
Interface Summary Interface Description Reference.Flag Expected flag (or lack of flag) on a class, method or field reference. -
Class Summary Class Description InstrumentationClassPredicate Reference This class represents a reference to a Java class used in an instrumentation advice code.Reference.Builder Reference.Field Reference.Method Reference.Source Represents the source (file name, line number) of a reference. -
Enum Summary Enum Description Reference.Flag.ManifestationFlag The constants of this enum describe whether a method or class is abstract, final or non-final.Reference.Flag.MinimumVisibilityFlag The constants of this enum represent the minimum visibility flag required by a type access, method call or field access.Reference.Flag.OwnershipFlag The constants of this enum describe whether a method/field is static or not.Reference.Flag.VisibilityFlag The constants of this enum represent the exact visibility of a referenced class, method or field.