Package io.opentelemetry.javaagent.tooling
-
Interface Summary Interface Description CommonTaskExecutor.Task<T> TypeInstrumentation Interface representing a single type instrumentation. -
Class Summary Class Description AddThreadDetailsSpanProcessor AgentInstaller AgentTooling This class contains class references for objects shared by the agent installer as well as muzzle (both compile and runtime).AgentTracerProviderConfigurer AutoVersionResourceProvider ClassHierarchyIterable Iterates over a class, its superclass, and its interfaces in the following breath-first-like manner:CommonTaskExecutor Constants Some useful constants.DaemonThreadFactory AThreadFactoryimplementation that starts allThreadas daemons.ExporterClassLoader GuavaWeakCache<K,V> No null keys nor null values are permitted.GuavaWeakCache.Provider<K,V> HelperInjector Injects instrumentation helper classes into the user's classloader.InstrumentationModule Instrumentation module groups several connectedTypeInstrumentations together, sharing classloader matcher, helper classes, muzzle safety checks, etc.OpenTelemetryInstaller ShadingRemapper ShadingRemapper.Rule TransformSafeLogger Debug logging that is performed under class file transform needs to use this class, because gradle deadlocks sporadically under the following sequence: Gradle triggers a class to load while it is holding a lock Class file transform occurs (under this lock) and the agent writes to System.out (Because gradle hijacks System.out), gradle is called from inside of the class file transform Gradle tries to grab a different lock during it's implementation of System.outUtils VersionLogger