Package io.opentelemetry.javaagent.tooling.util
-
Interface Summary Interface Description Trie<V> A prefix tree that maps from the longest matching prefix to a valueV.Trie.Builder<V>
| Interface | Description |
|---|---|
| Trie<V> |
A prefix tree that maps from the longest matching prefix to a value
V. |
| Trie.Builder<V> |