JavaScript is disabled on your browser.
Skip navigation links
Overview
Package
Class
Tree
Deprecated
Index
Help
All Classes
SEARCH:
JavaScript is disabled on your browser.
All Classes
All Classes
Interface Summary
Class Summary
Enum Summary
Class
Description
AdditionalLibraryIgnoredTypesConfigurer
Additional global ignore settings that are used to reduce number of classes we try to apply expensive matchers to.
AddThreadDetailsSpanProcessor
AgentExtension
An
AgentExtension
provides a way to modify/enrich the OpenTelemetry Javaagent behavior.
AgentInstaller
AgentStarterImpl
Main entry point into code that is running inside agent class loader, used reflectively from
io.opentelemetry.javaagent.bootstrap.AgentInitializer
.
AgentTracerProviderConfigurer
AutoVersionResourceProvider
BootstrapPackagesBuilderImpl
ConfigInitializer
Constants
Some useful constants.
ExceptionHandlers
ExtensionClassLoader
This class creates a classloader which encapsulates arbitrary extensions for Otel Java instrumentation agent.
GlobalIgnoredTypesConfigurer
IgnoreAllow
IgnoredClassLoadersMatcher
IgnoredTypesBuilderImpl
IgnoredTypesMatcher
InputStreamUrlConnection
InstrumentationLoader
InstrumentationModuleInstaller
LoggingFailSafeMatcher
<
T
>
A fail-safe matcher catches exceptions that are thrown by a delegate matcher and returns
false
.
MethodsConfigurationParser
MuzzleFailureCounter
OpenTelemetryInstaller
RemappingUrlConnection
SafeServiceLoader
ShadingRemapper
ShadingRemapper.Rule
Trie
<
V
>
A prefix tree that maps from the longest matching prefix to a value
V
.
Trie.Builder
<
V
>
UserExcludedClassesConfigurer
Utils
VersionLogger
VirtualFieldImplementationInstaller
VirtualFieldImplementationInstallerFactory
WeakRefAsyncOperationEndStrategies