All Classes
-
All Classes Interface Summary Class Summary Enum Summary Class Description AdditionalLibraryIgnoredTypesConfigurer Additional global ignore settings that are used to reduce number of classes we try to apply expensive matchers to.AddThreadDetailsSpanProcessor AgentCachingPoolStrategy There two core parts to the cache...AgentInstaller AgentLocationStrategy Locate resources with the loading classloader.AgentTooling This class contains class references for objects shared by the agent installer as well as muzzle (both compile and runtime).AgentTracerProviderConfigurer AutoVersionResourceProvider BootstrapPackagesBuilderImpl ConfigInitializer Constants Some useful constants.ExceptionHandlers ExporterClassLoader Deprecated. ExtensionClassLoader This class creates a classloader which encapsulates arbitrary extensions for Otel Java instrumentation agent.FieldBackedProvider InstrumentationContextProvider which stores context in a field that is injected into a class and falls back to global map if field was not injected.GlobalIgnoredTypesConfigurer HelperInjector Injects instrumentation helper classes into the user's classloader.IgnoreAllow IgnoredClassLoadersMatcher IgnoredTypesBuilderImpl IgnoredTypesMatcher InputStreamUrlConnection InstrumentationContextProvider InstrumentationLoader InstrumentationModuleInstaller LoggingFailSafeMatcher<T> A fail-safe matcher catches exceptions that are thrown by a delegate matcher and returnsfalse.MethodsConfigurationParser Mismatch A mismatch between aClassRefand a runtime class.Mismatch.MissingClass Mismatch.MissingField Mismatch.MissingFlag Mismatch.MissingMethod Mismatch.ReferenceCheckError Fallback mismatch in case an unexpected exception occurs during reference checking.MuzzleCodeGenerationPlugin This class is a ByteBuddy build plugin that is responsible for generating actual implementation of someInstrumentationModulemethods.MuzzleGradlePluginUtil Entry point for the muzzle gradle plugin.NoopContextProvider OpenTelemetryInstaller OpenTelemetryInstaller.OpenTelemetryMetricsConfigurer ReferenceCollector LinkedHashMapis used for reference map to guarantee a deterministic order of iteration, so that bytecode generated based on it would also be deterministic.ReferenceMatcher Matches a set of references against a classloader.RemappingUrlConnection SafeServiceLoader ShadingRemapper ShadingRemapper.Rule TransformSafeLogger Debug logging that is performed under class file transform needs to use this class, because gradle deadlocks sporadically under the following sequence: Gradle triggers a class to load while it is holding a lock Class file transform occurs (under this lock) and the agent writes to System.out (Because gradle hijacks System.out), gradle is called from inside of the class file transform Gradle tries to grab a different lock during it's implementation of System.outUserExcludedClassesConfigurer Utils VersionLogger WeakRefAsyncOperationEndStrategies