All Classes
-
All Classes Interface Summary Class Summary Exception Summary Class Description AdditionalLibraryIgnoresMatcher Additional global matchers that are used to reduce number of classes we try to apply expensive matchers to.AddThreadDetailsSpanProcessor AgentCachingPoolStrategy NEW (Jan 2020) Custom Pool strategy.AgentInstaller AgentLocationStrategy Locate resources with the loading classloader.AgentTooling This class contains class references for objects shared by the agent installer as well as muzzle (both compile and runtime).AgentTracerProviderConfigurer AutoVersionResourceProvider ConfigInitializer Constants Some useful constants.ExceptionHandlers ExporterClassLoader FieldBackedProvider InstrumentationContextProvider which stores context in a field that is injected into a class and falls back to global map if field was not injected.GlobalClassloaderIgnoresMatcher GlobalIgnoresMatcher Global ignores matcher used by the agent.HelperInjector Injects instrumentation helper classes into the user's classloader.InstrumentationClassPredicate InstrumentationContextProvider InstrumentationLoader InstrumentationModuleInstaller MethodsConfigurationParser Mismatch A mismatch between aReferenceand a runtime class.Mismatch.MissingClass Mismatch.MissingField Mismatch.MissingFlag Mismatch.MissingMethod Mismatch.ReferenceCheckError Fallback mismatch in case an unexpected exception occurs during reference checking.MuzzleCodeGenerationPlugin This class is a ByteBuddy build plugin that is responsible for generating actual implementation of someInstrumentationModulemethods.MuzzleCompilationException MuzzleGradlePluginUtil Entry point for the muzzle gradle plugin.NoopContextProvider OpenTelemetryInstaller ReferenceCollector LinkedHashMapis used for reference map to guarantee a deterministic order of iteration, so that bytecode generated based on it would also be deterministic.ReferenceMatcher Matches a set of references against a classloader.ShadingRemapper ShadingRemapper.Rule TransformSafeLogger Debug logging that is performed under class file transform needs to use this class, because gradle deadlocks sporadically under the following sequence: Gradle triggers a class to load while it is holding a lock Class file transform occurs (under this lock) and the agent writes to System.out (Because gradle hijacks System.out), gradle is called from inside of the class file transform Gradle tries to grab a different lock during it's implementation of System.outUtils VersionLogger