All Classes Interface Summary Class Summary Enum Summary
| Class |
Description |
| AdditionalLibraryIgnoresMatcher<T extends net.bytebuddy.description.type.TypeDescription> |
Additional global matchers that are used to reduce number of classes we try to apply expensive
matchers to.
|
| AddThreadDetailsSpanProcessor |
|
| AgentCachingPoolStrategy |
NEW (Jan 2020) Custom Pool strategy.
|
| AgentElementMatchers |
This class provides some custom ByteBuddy element matchers to use when applying instrumentation.
|
| AgentInstaller |
|
| AgentLocationStrategy |
Locate resources with the loading classloader.
|
| AgentTooling |
This class contains class references for objects shared by the agent installer as well as muzzle
(both compile and runtime).
|
| AgentTransformers |
|
| AutoVersionResourceProvider |
|
| ClassHierarchyIterable |
Iterates over a class, its superclass, and its interfaces in the following breath-first-like
manner:
|
| ClassLoaderMatcher |
|
| CommonTaskExecutor |
|
| CommonTaskExecutor.Task<T> |
|
| ConfigInitializer |
|
| Constants |
Some useful constants.
|
| DaemonThreadFactory |
A ThreadFactory implementation that starts all Thread as daemons.
|
| ExceptionHandlers |
|
| ExporterClassLoader |
|
| FieldBackedProvider |
InstrumentationContextProvider which stores context in a field that is injected into a class and
falls back to global map if field was not injected.
|
| GlobalIgnoresMatcher<T extends net.bytebuddy.description.type.TypeDescription> |
Global ignores matcher used by the agent.
|
| GuavaWeakCache<K,V> |
No null keys nor null values are permitted.
|
| GuavaWeakCache.Provider<K,V> |
|
| HelperInjector |
Injects instrumentation helper classes into the user's classloader.
|
| HelperReferenceWrapper |
This class provides a common interface for Reference and TypeDescription.
|
| HelperReferenceWrapper.Factory |
|
| HelperReferenceWrapper.Method |
|
| InstrumentationClassPredicate |
|
| InstrumentationContextProvider |
|
| InstrumentationModule |
Instrumentation module groups several connected TypeInstrumentations together, sharing
classloader matcher, helper classes, muzzle safety checks, etc.
|
| Mismatch |
A mismatch between a Reference and a runtime class.
|
| Mismatch.MissingClass |
|
| Mismatch.MissingField |
|
| Mismatch.MissingFlag |
|
| Mismatch.MissingMethod |
|
| Mismatch.ReferenceCheckError |
Fallback mismatch in case an unexpected exception occurs during reference checking.
|
| MuzzleCodeGenerationPlugin |
|
| MuzzleGradlePluginUtil |
Entry point for the muzzle gradle plugin.
|
| NameMatchers |
|
| NoopContextProvider |
|
| OpenTelemetryInstaller |
|
| PropagatorsInitializer |
|
| Reference |
This class represents a reference to a Java class used in an instrumentation advice code.
|
| Reference.Builder |
|
| Reference.Field |
|
| Reference.Flag |
Expected flag (or lack of flag) on a class, method or field reference.
|
| Reference.Flag.ManifestationFlag |
The constants of this enum describe whether a method or class is abstract, final or
non-final.
|
| Reference.Flag.MinimumVisibilityFlag |
The constants of this enum represent the minimum visibility flag required by a type access,
method call or field access.
|
| Reference.Flag.OwnershipFlag |
The constants of this enum describe whether a method/field is static or not.
|
| Reference.Flag.VisibilityFlag |
The constants of this enum represent the exact visibility of a referenced class, method or
field.
|
| Reference.Method |
|
| Reference.Source |
Represents the source (file name, line number) of a reference.
|
| ReferenceCollector |
LinkedHashMap is used for reference map to guarantee a deterministic order of iteration,
so that bytecode generated based on it would also be deterministic.
|
| ReferenceMatcher |
Matches a set of references against a classloader.
|
| ShadingRemapper |
|
| ShadingRemapper.Rule |
|
| TypeInstrumentation |
Interface representing a single type instrumentation.
|
| Utils |
|
| VersionLogger |
|