Class AgentInstaller
java.lang.Object
io.opentelemetry.javaagent.tooling.AgentInstaller
-
Method Summary
Modifier and TypeMethodDescriptionstatic voidstatic net.bytebuddy.agent.builder.ResettableClassFileTransformerinstallBytebuddyAgent(Instrumentation inst, Iterable<io.opentelemetry.javaagent.extension.AgentListener> agentListeners) Install the core bytebuddy agent along with all implementations ofInstrumentationModule.static voidregisterClassLoadCallback(String className, Runnable callback) Register a callback to run when a class is loading.
-
Method Details
-
installBytebuddyAgent
-
installBytebuddyAgent
public static net.bytebuddy.agent.builder.ResettableClassFileTransformer installBytebuddyAgent(Instrumentation inst, Iterable<io.opentelemetry.javaagent.extension.AgentListener> agentListeners) Install the core bytebuddy agent along with all implementations ofInstrumentationModule.- Parameters:
inst- Java Instrumentation used to install bytebuddy- Returns:
- the agent's class transformer
-
registerClassLoadCallback
Register a callback to run when a class is loading.Caveats:
- This callback will be invoked by a jvm class transformer.
- Classes filtered out by
AgentInstaller's skip list will not be matched.
- Parameters:
className- name of the class to match againstcallback- runnable to invoke when class name matches
-