Class AgentInstaller


  • public class AgentInstaller
    extends Object
    • Method Detail

      • installBytebuddyAgent

        public static void installBytebuddyAgent​(Instrumentation inst)
      • installBytebuddyAgent

        public static net.bytebuddy.agent.builder.ResettableClassFileTransformer installBytebuddyAgent​(Instrumentation inst,
                                                                                                       Iterable<io.opentelemetry.javaagent.extension.AgentListener> agentListeners)
        Install the core bytebuddy agent along with all implementations of InstrumentationModule.
        Parameters:
        inst - Java Instrumentation used to install bytebuddy
        Returns:
        the agent's class transformer
      • registerClassLoadCallback

        public static void registerClassLoadCallback​(String className,
                                                     Runnable callback)
        Register a callback to run when a class is loading.

        Caveats:

        • This callback will be invoked by a jvm class transformer.
        • Classes filtered out by AgentInstaller's skip list will not be matched.
        Parameters:
        className - name of the class to match against
        callback - runnable to invoke when class name matches