Class AgentTooling


  • public class AgentTooling
    extends Object
    This class contains class references for objects shared by the agent installer as well as muzzle (both compile and runtime). Extracted out from AgentInstaller to begin separating some of the logic out.
    • Constructor Detail

      • AgentTooling

        public AgentTooling()
    • Method Detail

      • newWeakCache

        public static <K,​V> io.opentelemetry.javaagent.bootstrap.WeakCache<K,​V> newWeakCache()
      • newWeakCache

        public static <K,​V> io.opentelemetry.javaagent.bootstrap.WeakCache<K,​V> newWeakCache​(long maxSize)