Class AgentTooling
- java.lang.Object
-
- io.opentelemetry.javaagent.tooling.AgentTooling
-
public class AgentTooling extends Object
This class contains class references for objects shared by the agent installer as well as muzzle (both compile and runtime). Extracted out from AgentInstaller to begin separating some of the logic out.
-
-
Constructor Summary
Constructors Constructor Description AgentTooling()
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static AgentLocationStrategylocationStrategy()static <K,V>
io.opentelemetry.javaagent.bootstrap.WeakCache<K,V>newWeakCache()static <K,V>
io.opentelemetry.javaagent.bootstrap.WeakCache<K,V>newWeakCache(long maxSize)static AgentCachingPoolStrategypoolStrategy()
-
-
-
Method Detail
-
newWeakCache
public static <K,V> io.opentelemetry.javaagent.bootstrap.WeakCache<K,V> newWeakCache()
-
newWeakCache
public static <K,V> io.opentelemetry.javaagent.bootstrap.WeakCache<K,V> newWeakCache(long maxSize)
-
locationStrategy
public static AgentLocationStrategy locationStrategy()
-
poolStrategy
public static AgentCachingPoolStrategy poolStrategy()
-
-