Class ClassLoaderMatcher
- java.lang.Object
-
- io.opentelemetry.javaagent.tooling.ClassLoaderMatcher
-
public final class ClassLoaderMatcher extends java.lang.Object
-
-
Field Summary
Fields Modifier and Type Field Description static java.lang.ClassLoaderBOOTSTRAP_CLASSLOADER
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<java.lang.ClassLoader>hasClassesNamed(java.lang.String... classNames)NOTICE: Does not match the bootstrap classpath.static net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<java.lang.ClassLoader>skipClassLoader()
-
-
-
Method Detail
-
skipClassLoader
public static net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<java.lang.ClassLoader> skipClassLoader()
-
hasClassesNamed
public static net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<java.lang.ClassLoader> hasClassesNamed(java.lang.String... classNames)
NOTICE: Does not match the bootstrap classpath. Don't use with classes expected to be on the bootstrap.- Parameters:
classNames- list of names to match. returns true if empty.- Returns:
- true if class is available as a resource and not the bootstrap classloader.
-
-