Class Constants
- java.lang.Object
-
- io.opentelemetry.javaagent.tooling.Constants
-
public final class Constants extends Object
Some useful constants.Idea here is to keep this class safe to inject into client's class loader.
-
-
Field Summary
Fields Modifier and Type Field Description static String[]AGENT_PACKAGE_PREFIXESstatic String[]BOOTSTRAP_PACKAGE_PREFIXESpackages which will be loaded on the bootstrap classloader.
-