Class Constants


  • public final class Constants
    extends java.lang.Object
    Some useful constants.

    Idea here is to keep this class safe to inject into client's class loader.

    • Method Summary

      • Methods inherited from class java.lang.Object

        equals, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Field Detail

      • BOOTSTRAP_PACKAGE_PREFIXES

        public static final java.lang.String[] BOOTSTRAP_PACKAGE_PREFIXES
        packages which will be loaded on the bootstrap classloader.
      • AGENT_PACKAGE_PREFIXES

        public static final java.lang.String[] AGENT_PACKAGE_PREFIXES