Interface LoggingCustomizer


public interface LoggingCustomizer
  • Method Summary

    Modifier and Type
    Method
    Description
    void
     
    void
    Register a callback which will be called on synchronous startup failure (including if init() fails).
    void
    Register a callback which will be called on synchronous startup success.
  • Method Details

    • init

      void init()
    • onStartupSuccess

      void onStartupSuccess()
      Register a callback which will be called on synchronous startup success.

      Synchronous startup may or may not include running AgentListener.afterAgent(AutoConfiguredOpenTelemetrySdk)" listeners.

    • onStartupFailure

      void onStartupFailure(Throwable throwable)
      Register a callback which will be called on synchronous startup failure (including if init() fails).

      Synchronous startup may or may not include running AgentListener.afterAgent(AutoConfiguredOpenTelemetrySdk)" listeners.