Interface LoggingCustomizer
public interface LoggingCustomizer
-
Method Summary
Modifier and TypeMethodDescriptionvoidinit()voidonStartupFailure(Throwable throwable) Register a callback which will be called on synchronous startup failure (including ifinit()fails).voidRegister a callback which will be called on synchronous startup success.
-
Method Details
-
init
void init() -
onStartupSuccess
void onStartupSuccess()Register a callback which will be called on synchronous startup success.Synchronous startup may or may not include running
AgentListener.afterAgent(AutoConfiguredOpenTelemetrySdk)" listeners. -
onStartupFailure
Register a callback which will be called on synchronous startup failure (including ifinit()fails).Synchronous startup may or may not include running
AgentListener.afterAgent(AutoConfiguredOpenTelemetrySdk)" listeners.
-