Interface BootstrapPackagesBuilder
- All Known Implementing Classes:
BootstrapPackagesBuilderImpl
public interface BootstrapPackagesBuilder
This interface exposes a way to define which packages/classes are present in the bootstrap
classloader.
This interface should not be implemented by the javaagent extension developer - the javaagent will provide the implementation.
-
Method Summary
Modifier and TypeMethodDescriptionMarkclassNameOrPrefixas one that belongs to the bootstrap classloader.addAll(Collection<String> classNamesOrPrefixes) Mark all elements ofclassNamesOrPrefixesas ones that belongs to the bootstrap classloader.
-
Method Details
-
add
MarkclassNameOrPrefixas one that belongs to the bootstrap classloader.- Returns:
this
-
addAll
Mark all elements ofclassNamesOrPrefixesas ones that belongs to the bootstrap classloader.- Returns:
this
-