Interface InstrumentationContextProvider
-
- All Known Implementing Classes:
FieldBackedProvider,NoopContextProvider
public interface InstrumentationContextProvider
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description net.bytebuddy.agent.builder.AgentBuilder.Identified.ExtendableadditionalInstrumentation(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)Hook to define additional instrumentation.net.bytebuddy.agent.builder.AgentBuilder.Identified.ExtendableinstrumentationTransformer(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)Hook to provide an agent builder after advice is applied to target class.
-
-
-
Method Detail
-
instrumentationTransformer
net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable instrumentationTransformer(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)
Hook to provide an agent builder after advice is applied to target class. Used to implement context-store lookup.
-
additionalInstrumentation
net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable additionalInstrumentation(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)
Hook to define additional instrumentation. Run at instrumentation advice is hooked up.
-
-