Class NoopContextProvider

    • Method Summary

      All Methods Instance Methods Concrete Methods 
      Modifier and Type Method Description
      net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable additionalInstrumentation​(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)
      Hook to define additional instrumentation.
      net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable instrumentationTransformer​(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)
      Hook to provide an agent builder after advice is applied to target class.
      • Methods inherited from class java.lang.Object

        equals, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Method Detail

      • instrumentationTransformer

        public net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable instrumentationTransformer​(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)
        Description copied from interface: InstrumentationContextProvider
        Hook to provide an agent builder after advice is applied to target class. Used to implement context-store lookup.
        Specified by:
        instrumentationTransformer in interface InstrumentationContextProvider
      • additionalInstrumentation

        public net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable additionalInstrumentation​(net.bytebuddy.agent.builder.AgentBuilder.Identified.Extendable builder)
        Description copied from interface: InstrumentationContextProvider
        Hook to define additional instrumentation. Run at instrumentation advice is hooked up.
        Specified by:
        additionalInstrumentation in interface InstrumentationContextProvider