Class InstrumentationLoader
- java.lang.Object
-
- io.opentelemetry.javaagent.tooling.instrumentation.InstrumentationLoader
-
- All Implemented Interfaces:
io.opentelemetry.javaagent.extension.Ordered,AgentExtension
@AutoService(AgentExtension.class) public class InstrumentationLoader extends Object implements AgentExtension
-
-
Constructor Summary
Constructors Constructor Description InstrumentationLoader()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description net.bytebuddy.agent.builder.AgentBuilderextend(net.bytebuddy.agent.builder.AgentBuilder agentBuilder)Extend the passedagentBuilderwith custom logic (e.g. instrumentation).StringextensionName()Returns the name of the extension.
-
-
-
Method Detail
-
extend
public net.bytebuddy.agent.builder.AgentBuilder extend(net.bytebuddy.agent.builder.AgentBuilder agentBuilder)
Description copied from interface:AgentExtensionExtend the passedagentBuilderwith custom logic (e.g. instrumentation).- Specified by:
extendin interfaceAgentExtension- Returns:
- The customized agent. Note that this method MUST return a non-null
AgentBuilderinstance that contains all customizations defined in this extension.
-
extensionName
public String extensionName()
Description copied from interface:AgentExtensionReturns the name of the extension. It does not have to be unique, but it should be human-readable: javaagent uses the extension name in its logs.- Specified by:
extensionNamein interfaceAgentExtension
-
-