Class AdditionalLibraryIgnoresMatcher<T extends net.bytebuddy.description.type.TypeDescription>

  • All Implemented Interfaces:
    net.bytebuddy.matcher.ElementMatcher<T>, net.bytebuddy.matcher.ElementMatcher.Junction<T>

    public class AdditionalLibraryIgnoresMatcher<T extends net.bytebuddy.description.type.TypeDescription>
    extends net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<T>
    Additional global matchers that are used to reduce number of classes we try to apply expensive matchers to.

    This is separated from GlobalIgnoresMatcher to allow for better testing. The idea is that we should be able to remove this matcher from the agent and all tests should still pass. Moreover, no classes matched by this matcher should be modified during test run.

    TODO: refactor/optimize this class (spring boot approach as a possible solution)

    • Nested Class Summary

      • Nested classes/interfaces inherited from interface net.bytebuddy.matcher.ElementMatcher

        net.bytebuddy.matcher.ElementMatcher.Junction<S extends java.lang.Object>
      • Nested classes/interfaces inherited from interface net.bytebuddy.matcher.ElementMatcher.Junction

        net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<V extends java.lang.Object>, net.bytebuddy.matcher.ElementMatcher.Junction.Conjunction<W extends java.lang.Object>, net.bytebuddy.matcher.ElementMatcher.Junction.Disjunction<W extends java.lang.Object>
    • Method Summary

      All Methods Static Methods Instance Methods Concrete Methods 
      Modifier and Type Method Description
      static <T extends net.bytebuddy.description.type.TypeDescription>
      net.bytebuddy.matcher.ElementMatcher.Junction<T>
      additionalLibraryIgnoresMatcher()  
      boolean equals​(java.lang.Object obj)  
      int hashCode()  
      boolean matches​(T target)
      Be very careful about the types of matchers used in this section as they are called on every class load, so they must be fast.
      java.lang.String toString()  
      • Methods inherited from class net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase

        and, or
      • Methods inherited from class java.lang.Object

        getClass, notify, notifyAll, wait, wait, wait
    • Constructor Detail

      • AdditionalLibraryIgnoresMatcher

        public AdditionalLibraryIgnoresMatcher()
    • Method Detail

      • additionalLibraryIgnoresMatcher

        public static <T extends net.bytebuddy.description.type.TypeDescription> net.bytebuddy.matcher.ElementMatcher.Junction<T> additionalLibraryIgnoresMatcher()
      • matches

        public boolean matches​(T target)
        Be very careful about the types of matchers used in this section as they are called on every class load, so they must be fast. Generally speaking try to only use name matchers as they don't have to load additional info.
      • toString

        public java.lang.String toString()
        Overrides:
        toString in class java.lang.Object
      • equals

        public boolean equals​(java.lang.Object obj)
        Overrides:
        equals in class java.lang.Object
      • hashCode

        public int hashCode()
        Overrides:
        hashCode in class java.lang.Object