Class GlobalIgnoresMatcher<T extends net.bytebuddy.description.type.TypeDescription>
- java.lang.Object
-
- net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<T>
-
- io.opentelemetry.javaagent.tooling.matcher.GlobalIgnoresMatcher<T>
-
- All Implemented Interfaces:
net.bytebuddy.matcher.ElementMatcher<T>,net.bytebuddy.matcher.ElementMatcher.Junction<T>
public class GlobalIgnoresMatcher<T extends net.bytebuddy.description.type.TypeDescription> extends net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<T>Global ignores matcher used by the agent.This matcher services two main purposes:
-
Ignore classes that are unsafe or pointless to transform. 'System' level classes like jvm
classes or groovy classes, other tracers, debuggers, etc.
-
Uses
AdditionalLibraryIgnoresMatcherto also ignore additional classes to minimize number of classes we apply expensive matchers to.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface net.bytebuddy.matcher.ElementMatcher
net.bytebuddy.matcher.ElementMatcher.Junction<S extends Object>
-
Nested classes/interfaces inherited from interface net.bytebuddy.matcher.ElementMatcher.Junction
net.bytebuddy.matcher.ElementMatcher.Junction.AbstractBase<V extends Object>, net.bytebuddy.matcher.ElementMatcher.Junction.Conjunction<W extends Object>, net.bytebuddy.matcher.ElementMatcher.Junction.Disjunction<W extends Object>
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)static <T extends net.bytebuddy.description.type.TypeDescription>
net.bytebuddy.matcher.ElementMatcher.Junction<T>globalIgnoresMatcher(boolean skipAdditionalLibraryMatcher, io.opentelemetry.javaagent.spi.IgnoreMatcherProvider ignoreMatcherProviders)inthashCode()booleanmatches(T target)Be very careful about the types of matchers used in this section as they are called on every class load, so they must be fast.StringtoString()
-
-
-
Method Detail
-
globalIgnoresMatcher
public static <T extends net.bytebuddy.description.type.TypeDescription> net.bytebuddy.matcher.ElementMatcher.Junction<T> globalIgnoresMatcher(boolean skipAdditionalLibraryMatcher, io.opentelemetry.javaagent.spi.IgnoreMatcherProvider ignoreMatcherProviders)
-
matches
public boolean matches(T target)
Be very careful about the types of matchers used in this section as they are called on every class load, so they must be fast. Generally speaking try to only use name matchers as they don't have to load additional info.
-
-