Package io.opentelemetry.javaagent.tooling.matcher
-
Class Summary Class Description AdditionalLibraryIgnoresMatcher<T extends net.bytebuddy.description.type.TypeDescription> Additional global matchers that are used to reduce number of classes we try to apply expensive matchers to.GlobalClassloaderIgnoresMatcher GlobalIgnoresMatcher<T extends net.bytebuddy.description.type.TypeDescription> Global ignores matcher used by the agent.