Class InstrumentationClassPredicate
- java.lang.Object
-
- io.opentelemetry.javaagent.tooling.muzzle.InstrumentationClassPredicate
-
public final class InstrumentationClassPredicate extends Object
-
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static booleanisInstrumentationClass(String className)Defines which classes are treated by muzzle as "internal", "helper" instrumentation classes.
-
-
-
Method Detail
-
isInstrumentationClass
public static boolean isInstrumentationClass(String className)
Defines which classes are treated by muzzle as "internal", "helper" instrumentation classes.This set of classes is defined by a package naming convention: all automatic and manual instrumentation classes and
javaagent.toolingclasses are treated as "helper" classes and are subjected to the reference collection process. All others (includinginstrumentation-apiandjavaagent-apimodules are not scanned for referenced (but references to them are collected).
-
-