Class InstrumentationClassPredicate


  • public final class InstrumentationClassPredicate
    extends java.lang.Object
    • Method Summary

      All Methods Static Methods Concrete Methods 
      Modifier and Type Method Description
      static boolean isInstrumentationClass​(java.lang.String className)
      Defines which classes are treated by muzzle as "internal", "helper" instrumentation classes.
      • Methods inherited from class java.lang.Object

        equals, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Method Detail

      • isInstrumentationClass

        public static boolean isInstrumentationClass​(java.lang.String className)
        Defines which classes are treated by muzzle as "internal", "helper" instrumentation classes.

        This set of classes is defined by a package naming convention: all automatic and manual instrumentation classes and javaagent.tooling classes are treated as "helper" classes and are subjected to the reference collection process. All others (including instrumentation-api and javaagent-api modules are not scanned for referenced (but references to them are collected).