Class Reference
- java.lang.Object
-
- io.opentelemetry.javaagent.tooling.muzzle.Reference
-
public final class Reference extends Object
This class represents a reference to a Java class used in an instrumentation advice code.LinkedHashSetis used for all sets to guarantee a deterministic order of iteration, so that bytecode generated based on them would also be deterministic.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classReference.Builderstatic classReference.Fieldstatic interfaceReference.FlagExpected flag (or lack of flag) on a class, method or field reference.static classReference.Methodstatic classReference.SourceRepresents the source (file name, line number) of a reference.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description StringgetClassName()Set<Reference.Field>getFields()Set<Reference.Flag>getFlags()Set<String>getInterfaces()Set<Reference.Method>getMethods()Set<Reference.Source>getSources()@Nullable StringgetSuperName()Referencemerge(Reference anotherReference)Create a new reference which combines this reference with another reference of the same type.StringtoString()
-
-
-
Method Detail
-
getClassName
public String getClassName()
-
getSuperName
public @Nullable String getSuperName()
-
getSources
public Set<Reference.Source> getSources()
-
getFlags
public Set<Reference.Flag> getFlags()
-
getMethods
public Set<Reference.Method> getMethods()
-
getFields
public Set<Reference.Field> getFields()
-
merge
public Reference merge(Reference anotherReference)
Create a new reference which combines this reference with another reference of the same type.- Parameters:
anotherReference- A reference to the same class- Returns:
- a new Reference which merges the two references
-
-