Class Reference
- java.lang.Object
-
- io.opentelemetry.javaagent.tooling.muzzle.Reference
-
public final class Reference extends java.lang.ObjectThis class represents a reference to a Java class used in an instrumentation advice code.LinkedHashSetis used for all sets to guarantee a deterministic order of iteration, so that bytecode generated based on them would also be deterministic.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classReference.Builderstatic classReference.Fieldstatic interfaceReference.FlagExpected flag (or lack of flag) on a class, method or field reference.static classReference.Methodstatic classReference.SourceRepresents the source (file name, line number) of a reference.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description java.lang.StringgetClassName()java.util.Set<Reference.Field>getFields()java.util.Set<Reference.Flag>getFlags()java.util.Set<java.lang.String>getInterfaces()java.util.Set<Reference.Method>getMethods()java.util.Set<Reference.Source>getSources()@Nullable java.lang.StringgetSuperName()Referencemerge(Reference anotherReference)Create a new reference which combines this reference with another reference of the same type.java.lang.StringtoString()
-
-
-
Method Detail
-
getClassName
public java.lang.String getClassName()
-
getSuperName
public @Nullable java.lang.String getSuperName()
-
getInterfaces
public java.util.Set<java.lang.String> getInterfaces()
-
getSources
public java.util.Set<Reference.Source> getSources()
-
getFlags
public java.util.Set<Reference.Flag> getFlags()
-
getMethods
public java.util.Set<Reference.Method> getMethods()
-
getFields
public java.util.Set<Reference.Field> getFields()
-
merge
public Reference merge(Reference anotherReference)
Create a new reference which combines this reference with another reference of the same type.- Parameters:
anotherReference- A reference to the same class- Returns:
- a new Reference which merges the two references
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-