Interface HelperReferenceWrapper
-
public interface HelperReferenceWrapperThis class provides a common interface forReferenceandTypeDescription.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static classHelperReferenceWrapper.Factorystatic classHelperReferenceWrapper.Method
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description Stream<HelperReferenceWrapper.Method>getMethods()Returns an iterable with all non-private, non-static methods declared in the wrapped type.Stream<HelperReferenceWrapper>getSuperTypes()Returns an iterable containing the wrapped type's super class (if exists) and implemented interfaces.booleanhasSuperTypes()Returns true if the wrapped type extends any class other thanObjector implements any interface.booleanisAbstract()
-
-
-
Method Detail
-
isAbstract
boolean isAbstract()
-
hasSuperTypes
boolean hasSuperTypes()
Returns true if the wrapped type extends any class other thanObjector implements any interface.
-
getSuperTypes
Stream<HelperReferenceWrapper> getSuperTypes()
Returns an iterable containing the wrapped type's super class (if exists) and implemented interfaces.
-
getMethods
Stream<HelperReferenceWrapper.Method> getMethods()
Returns an iterable with all non-private, non-static methods declared in the wrapped type.
-
-