Package io.opentelemetry.javaagent.tooling
-
Interface Summary Interface Description CommonTaskExecutor.Task<T> TypeInstrumentation Interface representing a single type instrumentation. -
Class Summary Class Description AddThreadDetailsSpanProcessor AgentInstaller AgentTooling This class contains class references for objects shared by the agent installer as well as muzzle (both compile and runtime).AgentTracerProviderConfigurer AutoVersionResourceProvider ClassHierarchyIterable Iterates over a class, its superclass, and its interfaces in the following breath-first-like manner:CommonTaskExecutor Constants Some useful constants.DaemonThreadFactory AThreadFactoryimplementation that starts allThreadas daemons.ExporterClassLoader GuavaWeakCache<K,V> No null keys nor null values are permitted.GuavaWeakCache.Provider<K,V> HelperInjector Injects instrumentation helper classes into the user's classloader.InstrumentationModule Instrumentation module groups several connectedTypeInstrumentations together, sharing classloader matcher, helper classes, muzzle safety checks, etc.OpenTelemetryInstaller ShadingRemapper ShadingRemapper.Rule Utils VersionLogger